#
# Get details of Syslog event data, parse and write to file
#
import sys
import re
import datetime

#
# Argument: directory to create logs in, (with backslash)
#
now = datetime.datetime.now()
logdir, logfile = ".\\", ".\\127.0.0.1.syslog.txt"

if len(sys.argv) < 2:
	print( "Logs directory name missing\n" )
	sys.exit( 3 )
else:
	logdir = sys.argv[ 1 ] 

#
# Prepare RE to match event data
#
eventre = re.compile('^\s*(.+?)\s*=\s*(.*?)\s*$')

#
# Prepare dictionary to store data; ensure "IP" entry isn't empty
#
eventdata = { "IP" : "127.0.0.1"}

#
# Read event data as provided in stdin, up to "EOF" terminator
#
for line in sys.stdin:
	rline = line.rstrip()
	if rline != "EOF":
		m = eventre.match( rline )
		# Assign data string to the key entered
		if m:
			eventdata[m.group(1)] = m.group(2)
		# We ignore lines not matching the 'key = value' pattern
		else:
			pass
	else:
		break
# stdin parsed; now append/create log file based upon IP and write event data
try:
	logfile = "%s%s.syslog.txt" % ( logdir, eventdata["IP"] )
	fh = open(logfile, "a")
	fh.write( "[Entry added: %s]\n" % str(now) )
	# We write all the values taken from event
	for key, value in eventdata.items():
		fh.write("  %s: %s\n" % (key, value))
	fh.close()
except IOError:
	print( "Can\'t append to file %s\n" % logfile )
	sys.exit( 3 )
	
sys.exit( 0 )
